Class: Onfido::AddressShared

Inherits:
Object
  • Object
show all
Defined in:
lib/onfido/models/address_shared.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AddressShared

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/onfido/models/address_shared.rb', line 133

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Onfido::AddressShared` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Onfido::AddressShared`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'flat_number')
    self.flat_number = attributes[:'flat_number']
  end

  if attributes.key?(:'building_number')
    self.building_number = attributes[:'building_number']
  end

  if attributes.key?(:'building_name')
    self.building_name = attributes[:'building_name']
  end

  if attributes.key?(:'street')
    self.street = attributes[:'street']
  end

  if attributes.key?(:'sub_street')
    self.sub_street = attributes[:'sub_street']
  end

  if attributes.key?(:'town')
    self.town = attributes[:'town']
  end

  if attributes.key?(:'postcode')
    self.postcode = attributes[:'postcode']
  else
    self.postcode = nil
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  else
    self.country = nil
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'line1')
    self.line1 = attributes[:'line1']
  end

  if attributes.key?(:'line2')
    self.line2 = attributes[:'line2']
  end

  if attributes.key?(:'line3')
    self.line3 = attributes[:'line3']
  end
end

Instance Attribute Details

#building_nameObject

The building name of this address



25
26
27
# File 'lib/onfido/models/address_shared.rb', line 25

def building_name
  @building_name
end

#building_numberObject

The building number of this address



22
23
24
# File 'lib/onfido/models/address_shared.rb', line 22

def building_number
  @building_number
end

#countryObject

The 3 character ISO country code of this address. For example, GBR is the country code for the United Kingdom



40
41
42
# File 'lib/onfido/models/address_shared.rb', line 40

def country
  @country
end

#flat_numberObject

The flat number of this address



19
20
21
# File 'lib/onfido/models/address_shared.rb', line 19

def flat_number
  @flat_number
end

#line1Object

Line 1 of the applicant’s address



46
47
48
# File 'lib/onfido/models/address_shared.rb', line 46

def line1
  @line1
end

#line2Object

Line 2 of the applicant’s address



49
50
51
# File 'lib/onfido/models/address_shared.rb', line 49

def line2
  @line2
end

#line3Object

Line 3 of the applicant’s address



52
53
54
# File 'lib/onfido/models/address_shared.rb', line 52

def line3
  @line3
end

#postcodeObject

The postcode or ZIP of the applicant’s address



37
38
39
# File 'lib/onfido/models/address_shared.rb', line 37

def postcode
  @postcode
end

#stateObject

The address state. US states must use the USPS abbreviation (see also ISO 3166-2:US), for example AK, CA, or TX.



43
44
45
# File 'lib/onfido/models/address_shared.rb', line 43

def state
  @state
end

#streetObject

The street of the applicant’s address



28
29
30
# File 'lib/onfido/models/address_shared.rb', line 28

def street
  @street
end

#sub_streetObject

The sub-street of the applicant’s address



31
32
33
# File 'lib/onfido/models/address_shared.rb', line 31

def sub_street
  @sub_street
end

#townObject

The town of the applicant’s address



34
35
36
# File 'lib/onfido/models/address_shared.rb', line 34

def town
  @town
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/onfido/models/address_shared.rb', line 354

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Onfido.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



95
96
97
# File 'lib/onfido/models/address_shared.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/onfido/models/address_shared.rb', line 100

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/onfido/models/address_shared.rb', line 77

def self.attribute_map
  {
    :'flat_number' => :'flat_number',
    :'building_number' => :'building_number',
    :'building_name' => :'building_name',
    :'street' => :'street',
    :'sub_street' => :'sub_street',
    :'town' => :'town',
    :'postcode' => :'postcode',
    :'country' => :'country',
    :'state' => :'state',
    :'line1' => :'line1',
    :'line2' => :'line2',
    :'line3' => :'line3'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/onfido/models/address_shared.rb', line 330

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



123
124
125
126
127
128
129
# File 'lib/onfido/models/address_shared.rb', line 123

def self.openapi_nullable
  Set.new([
    :'line1',
    :'line2',
    :'line3'
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/onfido/models/address_shared.rb', line 105

def self.openapi_types
  {
    :'flat_number' => :'String',
    :'building_number' => :'String',
    :'building_name' => :'String',
    :'street' => :'String',
    :'sub_street' => :'String',
    :'town' => :'String',
    :'postcode' => :'String',
    :'country' => :'CountryCodes',
    :'state' => :'String',
    :'line1' => :'String',
    :'line2' => :'String',
    :'line3' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/onfido/models/address_shared.rb', line 298

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      flat_number == o.flat_number &&
      building_number == o.building_number &&
      building_name == o.building_name &&
      street == o.street &&
      sub_street == o.sub_street &&
      town == o.town &&
      postcode == o.postcode &&
      country == o.country &&
      state == o.state &&
      line1 == o.line1 &&
      line2 == o.line2 &&
      line3 == o.line3
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



425
426
427
428
429
430
431
432
433
434
435
436
437
# File 'lib/onfido/models/address_shared.rb', line 425

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


317
318
319
# File 'lib/onfido/models/address_shared.rb', line 317

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



323
324
325
# File 'lib/onfido/models/address_shared.rb', line 323

def hash
  [flat_number, building_number, building_name, street, sub_street, town, postcode, country, state, line1, line2, line3].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/onfido/models/address_shared.rb', line 202

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @postcode.nil?
    invalid_properties.push('invalid value for "postcode", postcode cannot be nil.')
  end

  if @country.nil?
    invalid_properties.push('invalid value for "country", country cannot be nil.')
  end

  pattern = Regexp.new(/^[^!$%^*=<>]*$/)
  if !@line1.nil? && @line1 !~ pattern
    invalid_properties.push("invalid value for \"line1\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^[^!$%^*=<>]*$/)
  if !@line2.nil? && @line2 !~ pattern
    invalid_properties.push("invalid value for \"line2\", must conform to the pattern #{pattern}.")
  end

  pattern = Regexp.new(/^[^!$%^*=<>]*$/)
  if !@line3.nil? && @line3 !~ pattern
    invalid_properties.push("invalid value for \"line3\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



401
402
403
# File 'lib/onfido/models/address_shared.rb', line 401

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/onfido/models/address_shared.rb', line 407

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



395
396
397
# File 'lib/onfido/models/address_shared.rb', line 395

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



233
234
235
236
237
238
239
240
241
# File 'lib/onfido/models/address_shared.rb', line 233

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @postcode.nil?
  return false if @country.nil?
  return false if !@line1.nil? && @line1 !~ Regexp.new(/^[^!$%^*=<>]*$/)
  return false if !@line2.nil? && @line2 !~ Regexp.new(/^[^!$%^*=<>]*$/)
  return false if !@line3.nil? && @line3 !~ Regexp.new(/^[^!$%^*=<>]*$/)
  true
end