Class: Onfido::CheckBuilder
- Inherits:
-
Object
- Object
- Onfido::CheckBuilder
- Defined in:
- lib/onfido/models/check_builder.rb
Instance Attribute Summary collapse
-
#applicant_id ⇒ Object
The ID of the applicant to do the check on.
-
#applicant_provides_data ⇒ Object
Send an applicant form to applicant to complete to proceed with check.
-
#asynchronous ⇒ Object
Defaults to ‘true`.
-
#consider ⇒ Object
Array of names of particular reports to return consider as their results.
-
#document_ids ⇒ Object
Optional.
-
#privacy_notices_read_consent_given ⇒ Object
Returns the value of attribute privacy_notices_read_consent_given.
-
#redirect_uri ⇒ Object
For checks where ‘applicant_provides_data` is `true`, redirect to this URI when the applicant has submitted their data.
-
#report_configuration ⇒ Object
Returns the value of attribute report_configuration.
-
#report_names ⇒ Object
An array of report names (strings).
-
#sub_result ⇒ Object
Triggers responses for particular sub-results for sandbox Document reports.
-
#suppress_form_emails ⇒ Object
For checks where ‘applicant_provides_data` is `true`, applicant form will not be automatically sent if `suppress_form_emails` is set to `true`.
-
#tags ⇒ Object
Array of tags being assigned to this check.
-
#us_driving_licence ⇒ Object
Returns the value of attribute us_driving_licence.
-
#webhook_ids ⇒ Object
An array of webhook ids describing which webhooks to trigger for this check.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CheckBuilder
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CheckBuilder
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/onfido/models/check_builder.rb', line 123 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Onfido::CheckBuilder` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Onfido::CheckBuilder`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'webhook_ids') if (value = attributes[:'webhook_ids']).is_a?(Array) self.webhook_ids = value end end if attributes.key?(:'applicant_id') self.applicant_id = attributes[:'applicant_id'] else self.applicant_id = nil end if attributes.key?(:'applicant_provides_data') self.applicant_provides_data = attributes[:'applicant_provides_data'] else self.applicant_provides_data = false end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'redirect_uri') self.redirect_uri = attributes[:'redirect_uri'] end if attributes.key?(:'privacy_notices_read_consent_given') self. = attributes[:'privacy_notices_read_consent_given'] end if attributes.key?(:'report_names') if (value = attributes[:'report_names']).is_a?(Array) self.report_names = value end else self.report_names = nil end if attributes.key?(:'document_ids') if (value = attributes[:'document_ids']).is_a?(Array) self.document_ids = value end end if attributes.key?(:'asynchronous') self.asynchronous = attributes[:'asynchronous'] else self.asynchronous = true end if attributes.key?(:'suppress_form_emails') self.suppress_form_emails = attributes[:'suppress_form_emails'] end if attributes.key?(:'sub_result') self.sub_result = attributes[:'sub_result'] end if attributes.key?(:'consider') if (value = attributes[:'consider']).is_a?(Array) self.consider = value end end if attributes.key?(:'us_driving_licence') self.us_driving_licence = attributes[:'us_driving_licence'] end if attributes.key?(:'report_configuration') self.report_configuration = attributes[:'report_configuration'] end end |
Instance Attribute Details
#applicant_id ⇒ Object
The ID of the applicant to do the check on.
22 23 24 |
# File 'lib/onfido/models/check_builder.rb', line 22 def applicant_id @applicant_id end |
#applicant_provides_data ⇒ Object
Send an applicant form to applicant to complete to proceed with check. Defaults to false.
25 26 27 |
# File 'lib/onfido/models/check_builder.rb', line 25 def applicant_provides_data @applicant_provides_data end |
#asynchronous ⇒ Object
Defaults to ‘true`. If set to `false`, you will only receive a response when all reports in your check have completed.
42 43 44 |
# File 'lib/onfido/models/check_builder.rb', line 42 def asynchronous @asynchronous end |
#consider ⇒ Object
Array of names of particular reports to return consider as their results. This is a feature available in sandbox testing
51 52 53 |
# File 'lib/onfido/models/check_builder.rb', line 51 def consider @consider end |
#document_ids ⇒ Object
Optional. An array of document ids, for use with Document reports only. If omitted, the Document report will use the most recently uploaded document by default.
39 40 41 |
# File 'lib/onfido/models/check_builder.rb', line 39 def document_ids @document_ids end |
#privacy_notices_read_consent_given ⇒ Object
Returns the value of attribute privacy_notices_read_consent_given.
33 34 35 |
# File 'lib/onfido/models/check_builder.rb', line 33 def @privacy_notices_read_consent_given end |
#redirect_uri ⇒ Object
For checks where ‘applicant_provides_data` is `true`, redirect to this URI when the applicant has submitted their data.
31 32 33 |
# File 'lib/onfido/models/check_builder.rb', line 31 def redirect_uri @redirect_uri end |
#report_configuration ⇒ Object
Returns the value of attribute report_configuration.
55 56 57 |
# File 'lib/onfido/models/check_builder.rb', line 55 def report_configuration @report_configuration end |
#report_names ⇒ Object
An array of report names (strings).
36 37 38 |
# File 'lib/onfido/models/check_builder.rb', line 36 def report_names @report_names end |
#sub_result ⇒ Object
Triggers responses for particular sub-results for sandbox Document reports.
48 49 50 |
# File 'lib/onfido/models/check_builder.rb', line 48 def sub_result @sub_result end |
#suppress_form_emails ⇒ Object
For checks where ‘applicant_provides_data` is `true`, applicant form will not be automatically sent if `suppress_form_emails` is set to `true`. You can manually send the form at any time after the check has been created, using the link found in the form_uri attribute of the check object. Write-only. Defaults to false.
45 46 47 |
# File 'lib/onfido/models/check_builder.rb', line 45 def suppress_form_emails @suppress_form_emails end |
#tags ⇒ Object
Array of tags being assigned to this check.
28 29 30 |
# File 'lib/onfido/models/check_builder.rb', line 28 def @tags end |
#us_driving_licence ⇒ Object
Returns the value of attribute us_driving_licence.
53 54 55 |
# File 'lib/onfido/models/check_builder.rb', line 53 def us_driving_licence @us_driving_licence end |
#webhook_ids ⇒ Object
An array of webhook ids describing which webhooks to trigger for this check.
19 20 21 |
# File 'lib/onfido/models/check_builder.rb', line 19 def webhook_ids @webhook_ids end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/onfido/models/check_builder.rb', line 317 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Onfido.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/onfido/models/check_builder.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/onfido/models/check_builder.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/onfido/models/check_builder.rb', line 58 def self.attribute_map { :'webhook_ids' => :'webhook_ids', :'applicant_id' => :'applicant_id', :'applicant_provides_data' => :'applicant_provides_data', :'tags' => :'tags', :'redirect_uri' => :'redirect_uri', :'privacy_notices_read_consent_given' => :'privacy_notices_read_consent_given', :'report_names' => :'report_names', :'document_ids' => :'document_ids', :'asynchronous' => :'asynchronous', :'suppress_form_emails' => :'suppress_form_emails', :'sub_result' => :'sub_result', :'consider' => :'consider', :'us_driving_licence' => :'us_driving_licence', :'report_configuration' => :'report_configuration' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/onfido/models/check_builder.rb', line 293 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
114 115 116 117 118 119 |
# File 'lib/onfido/models/check_builder.rb', line 114 def self.openapi_all_of [ :'CheckRequest', :'CheckShared' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
108 109 110 111 |
# File 'lib/onfido/models/check_builder.rb', line 108 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/onfido/models/check_builder.rb', line 88 def self.openapi_types { :'webhook_ids' => :'Array<String>', :'applicant_id' => :'String', :'applicant_provides_data' => :'Boolean', :'tags' => :'Array<String>', :'redirect_uri' => :'String', :'privacy_notices_read_consent_given' => :'Boolean', :'report_names' => :'Array<ReportName>', :'document_ids' => :'Array<String>', :'asynchronous' => :'Boolean', :'suppress_form_emails' => :'Boolean', :'sub_result' => :'String', :'consider' => :'Array<ReportName>', :'us_driving_licence' => :'UsDrivingLicenceBuilder', :'report_configuration' => :'ReportConfiguration' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/onfido/models/check_builder.rb', line 259 def ==(o) return true if self.equal?(o) self.class == o.class && webhook_ids == o.webhook_ids && applicant_id == o.applicant_id && applicant_provides_data == o.applicant_provides_data && == o. && redirect_uri == o.redirect_uri && == o. && report_names == o.report_names && document_ids == o.document_ids && asynchronous == o.asynchronous && suppress_form_emails == o.suppress_form_emails && sub_result == o.sub_result && consider == o.consider && us_driving_licence == o.us_driving_licence && report_configuration == o.report_configuration end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/onfido/models/check_builder.rb', line 388 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
280 281 282 |
# File 'lib/onfido/models/check_builder.rb', line 280 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
286 287 288 |
# File 'lib/onfido/models/check_builder.rb', line 286 def hash [webhook_ids, applicant_id, applicant_provides_data, , redirect_uri, , report_names, document_ids, asynchronous, suppress_form_emails, sub_result, consider, us_driving_licence, report_configuration].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/onfido/models/check_builder.rb', line 214 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @applicant_id.nil? invalid_properties.push('invalid value for "applicant_id", applicant_id cannot be nil.') end if @report_names.nil? invalid_properties.push('invalid value for "report_names", report_names cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
364 365 366 |
# File 'lib/onfido/models/check_builder.rb', line 364 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
370 371 372 373 374 375 376 377 378 379 380 381 382 |
# File 'lib/onfido/models/check_builder.rb', line 370 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
358 359 360 |
# File 'lib/onfido/models/check_builder.rb', line 358 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
230 231 232 233 234 235 |
# File 'lib/onfido/models/check_builder.rb', line 230 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @applicant_id.nil? return false if @report_names.nil? true end |