Class: Onfido::CheckResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/onfido/models/check_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CheckResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/onfido/models/check_response.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Onfido::CheckResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Onfido::CheckResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'href')
    self.href = attributes[:'href']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'result')
    self.result = attributes[:'result']
  end

  if attributes.key?(:'form_uri')
    self.form_uri = attributes[:'form_uri']
  end

  if attributes.key?(:'results_uri')
    self.results_uri = attributes[:'results_uri']
  end

  if attributes.key?(:'report_ids')
    if (value = attributes[:'report_ids']).is_a?(Array)
      self.report_ids = value
    end
  end

  if attributes.key?(:'sandbox')
    self.sandbox = attributes[:'sandbox']
  end

  if attributes.key?(:'paused')
    self.paused = attributes[:'paused']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end
end

Instance Attribute Details

#created_atObject

The date and time when this check was created.



22
23
24
# File 'lib/onfido/models/check_response.rb', line 22

def created_at
  @created_at
end

#form_uriObject

A link to the applicant form, if ‘applicant_provides_data` is `true`.



33
34
35
# File 'lib/onfido/models/check_response.rb', line 33

def form_uri
  @form_uri
end

#hrefObject

The uri of this resource.



25
26
27
# File 'lib/onfido/models/check_response.rb', line 25

def href
  @href
end

#idObject

The unique identifier for the check.



19
20
21
# File 'lib/onfido/models/check_response.rb', line 19

def id
  @id
end

#pausedObject

Returns the value of attribute paused.



44
45
46
# File 'lib/onfido/models/check_response.rb', line 44

def paused
  @paused
end

#report_idsObject

An array of report ids.



39
40
41
# File 'lib/onfido/models/check_response.rb', line 39

def report_ids
  @report_ids
end

#resultObject

The overall result of the check, based on the results of the constituent reports.



30
31
32
# File 'lib/onfido/models/check_response.rb', line 30

def result
  @result
end

#results_uriObject

A link to the corresponding results page on the Onfido dashboard.



36
37
38
# File 'lib/onfido/models/check_response.rb', line 36

def results_uri
  @results_uri
end

#sandboxObject

Indicates whether the object was created in the sandbox or not.



42
43
44
# File 'lib/onfido/models/check_response.rb', line 42

def sandbox
  @sandbox
end

#statusObject

Returns the value of attribute status.



27
28
29
# File 'lib/onfido/models/check_response.rb', line 27

def status
  @status
end

#versionObject

Returns the value of attribute version.



46
47
48
# File 'lib/onfido/models/check_response.rb', line 46

def version
  @version
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/onfido/models/check_response.rb', line 284

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Onfido.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



88
89
90
# File 'lib/onfido/models/check_response.rb', line 88

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



93
94
95
# File 'lib/onfido/models/check_response.rb', line 93

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/onfido/models/check_response.rb', line 71

def self.attribute_map
  {
    :'id' => :'id',
    :'created_at' => :'created_at',
    :'href' => :'href',
    :'status' => :'status',
    :'result' => :'result',
    :'form_uri' => :'form_uri',
    :'results_uri' => :'results_uri',
    :'report_ids' => :'report_ids',
    :'sandbox' => :'sandbox',
    :'paused' => :'paused',
    :'version' => :'version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/onfido/models/check_response.rb', line 260

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



115
116
117
118
# File 'lib/onfido/models/check_response.rb', line 115

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/onfido/models/check_response.rb', line 98

def self.openapi_types
  {
    :'id' => :'String',
    :'created_at' => :'Time',
    :'href' => :'String',
    :'status' => :'CheckStatus',
    :'result' => :'String',
    :'form_uri' => :'String',
    :'results_uri' => :'String',
    :'report_ids' => :'Array<String>',
    :'sandbox' => :'Boolean',
    :'paused' => :'Boolean',
    :'version' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/onfido/models/check_response.rb', line 229

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created_at == o.created_at &&
      href == o.href &&
      status == o.status &&
      result == o.result &&
      form_uri == o.form_uri &&
      results_uri == o.results_uri &&
      report_ids == o.report_ids &&
      sandbox == o.sandbox &&
      paused == o.paused &&
      version == o.version
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/onfido/models/check_response.rb', line 355

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


247
248
249
# File 'lib/onfido/models/check_response.rb', line 247

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



253
254
255
# File 'lib/onfido/models/check_response.rb', line 253

def hash
  [id, created_at, href, status, result, form_uri, results_uri, report_ids, sandbox, paused, version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



187
188
189
190
191
192
193
194
195
# File 'lib/onfido/models/check_response.rb', line 187

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



331
332
333
# File 'lib/onfido/models/check_response.rb', line 331

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/onfido/models/check_response.rb', line 337

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



325
326
327
# File 'lib/onfido/models/check_response.rb', line 325

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



199
200
201
202
203
204
205
# File 'lib/onfido/models/check_response.rb', line 199

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  result_validator = EnumAttributeValidator.new('String', ["clear", "consider", "unknown_default_open_api"])
  return false unless result_validator.valid?(@result)
  true
end