Class: Onfido::Configuration

Inherits:
Object
  • Object
show all
Defined in:
lib/onfido/configuration.rb

Constant Summary collapse

REGIONS =
{
  EU: 'eu',
  CA: 'ca',
  US: 'us'
}.freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize {|_self| ... } ⇒ Configuration

Returns a new instance of Configuration.

Yields:

  • (_self)

Yield Parameters:



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/onfido/configuration.rb', line 175

def initialize
  @scheme = 'https'
  @host = 'api.eu.onfido.com'
  @base_path = '/v3.6'
  @server_index = nil
  @server_operation_index = {}
  @server_variables = {}
  @server_operation_variables = {}
  @api_key = {}
  @api_key_prefix = {}
  @client_side_validation = true
  @ssl_verify = true
  @ssl_verify_mode = nil
  @ssl_ca_file = nil
  @ssl_client_cert = nil
  @ssl_client_key = nil
  @middlewares = Hash.new { |h, k| h[k] = [] }
  @configure_connection_blocks = []
  @timeout = 30
  # return data as binary instead of file
  @return_binary_data = false
  @params_encoder = nil
  @debugging = false
  @ignore_operation_servers = false
  @inject_format = false
  @force_ending_format = false
  @oauth_mutex = Mutex.new 
  @logger = defined?(Rails) ? Rails.logger : Logger.new(STDOUT)

  use( Faraday::FollowRedirects::Middleware ) 

  yield(self) if block_given?
end

Instance Attribute Details

#access_tokenObject

Defines the access token (Bearer) used with OAuth2.



72
73
74
# File 'lib/onfido/configuration.rb', line 72

def access_token
  @access_token
end

#access_token_getterProc

Defines a Proc used to fetch or refresh access tokens (Bearer) used with OAuth2. Overrides the access_token if set

Returns:

  • (Proc)


77
78
79
# File 'lib/onfido/configuration.rb', line 77

def access_token_getter
  @access_token_getter
end

#api_keyHash

Defines API keys used with API Key authentications.

Examples:

parameter name is “api_key”, API key is “xxx” (e.g. “api_key=xxx” in query string)

config.api_key['api_key'] = 'xxx'

Returns:

  • (Hash)

    key: parameter name, value: parameter value (API key)



51
52
53
# File 'lib/onfido/configuration.rb', line 51

def api_key
  @api_key
end

#api_key_prefixHash

Defines API key prefixes used with API Key authentications.

Examples:

parameter name is “Authorization”, API key prefix is “Token” (e.g. “Authorization: Token xxx” in headers)

config.api_key_prefix['api_key'] = 'Token'

Returns:

  • (Hash)

    key: parameter name, value: API key prefix



59
60
61
# File 'lib/onfido/configuration.rb', line 59

def api_key_prefix
  @api_key_prefix
end

#base_pathObject

Defines url base path



31
32
33
# File 'lib/onfido/configuration.rb', line 31

def base_path
  @base_path
end

#client_side_validationtrue, false

Set this to false to skip client side validation in the operation. Default to true.

Returns:

  • (true, false)


127
128
129
# File 'lib/onfido/configuration.rb', line 127

def client_side_validation
  @client_side_validation
end

#debuggingtrue, false

Set this to enable/disable debugging. When enabled (set to true), HTTP request/response details will be logged with ‘logger.debug` (see the `logger` attribute). Default to false.

Returns:

  • (true, false)


97
98
99
# File 'lib/onfido/configuration.rb', line 97

def debugging
  @debugging
end

#force_ending_formatObject

Returns the value of attribute force_ending_format.



173
174
175
# File 'lib/onfido/configuration.rb', line 173

def force_ending_format
  @force_ending_format
end

#hostObject

Defines url host



28
29
30
# File 'lib/onfido/configuration.rb', line 28

def host
  @host
end

#ignore_operation_serverstrue, false

Set this to ignore operation servers for the API client. This is useful when you need to send requests to a different server than the one specified in the OpenAPI document. Will default to the base url defined in the spec but can be overridden by setting ‘scheme`, `host`, `base_path` directly. Default to false.

Returns:

  • (true, false)


105
106
107
# File 'lib/onfido/configuration.rb', line 105

def ignore_operation_servers
  @ignore_operation_servers
end

#inject_formatObject

Returns the value of attribute inject_format.



171
172
173
# File 'lib/onfido/configuration.rb', line 171

def inject_format
  @inject_format
end

#logger#debug

Defines the logger used for debugging. Default to ‘Rails.logger` (when in Rails) or logging to STDOUT.

Returns:

  • (#debug)


111
112
113
# File 'lib/onfido/configuration.rb', line 111

def logger
  @logger
end

#oauth_client_idString

Defines the OAuth2 client ID for client credentials flow.

Returns:

  • (String)


81
82
83
# File 'lib/onfido/configuration.rb', line 81

def oauth_client_id
  @oauth_client_id
end

#oauth_client_secretString

Defines the OAuth2 client secret for client credentials flow.

Returns:

  • (String)


85
86
87
# File 'lib/onfido/configuration.rb', line 85

def oauth_client_secret
  @oauth_client_secret
end

#params_encoderObject

Set this to customize parameters encoder of array parameter. Default to nil. Faraday uses NestedParamsEncoder when nil.

github.com/lostisland/faraday/tree/main/lib/faraday/encoders

See Also:

  • params_encoder option of Faraday. Related source code:


168
169
170
# File 'lib/onfido/configuration.rb', line 168

def params_encoder
  @params_encoder
end

#passwordString

Defines the password used with HTTP basic authentication.

Returns:

  • (String)


69
70
71
# File 'lib/onfido/configuration.rb', line 69

def password
  @password
end

#proxyObject

Proxy setting HTTP Proxy settings



161
162
163
# File 'lib/onfido/configuration.rb', line 161

def proxy
  @proxy
end

#return_binary_dataObject

Set this to return data as binary instead of downloading a temp file. When enabled (set to true) HTTP responses with return type ‘File` will be returned as a stream of binary data. Default to false.



90
91
92
# File 'lib/onfido/configuration.rb', line 90

def return_binary_data
  @return_binary_data
end

#schemeObject

Defines url scheme



25
26
27
# File 'lib/onfido/configuration.rb', line 25

def scheme
  @scheme
end

#server_indexObject

Define server configuration index



34
35
36
# File 'lib/onfido/configuration.rb', line 34

def server_index
  @server_index
end

#server_operation_indexObject

Define server operation configuration index



37
38
39
# File 'lib/onfido/configuration.rb', line 37

def server_operation_index
  @server_operation_index
end

#server_operation_variablesObject

Default server operation variables



43
44
45
# File 'lib/onfido/configuration.rb', line 43

def server_operation_variables
  @server_operation_variables
end

#server_variablesObject

Default server variables



40
41
42
# File 'lib/onfido/configuration.rb', line 40

def server_variables
  @server_variables
end

#ssl_ca_fileString

TLS/SSL setting Set this to customize the certificate file to verify the peer.

Returns:

  • (String)

    the path to the certificate file



149
150
151
# File 'lib/onfido/configuration.rb', line 149

def ssl_ca_file
  @ssl_ca_file
end

#ssl_client_certObject

TLS/SSL setting Client certificate file (for client certificate)



153
154
155
# File 'lib/onfido/configuration.rb', line 153

def ssl_client_cert
  @ssl_client_cert
end

#ssl_client_keyObject

TLS/SSL setting Client private key file (for client certificate)



157
158
159
# File 'lib/onfido/configuration.rb', line 157

def ssl_client_key
  @ssl_client_key
end

#ssl_verifytrue, false

Note:

Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.

TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server. Default to true.

Returns:

  • (true, false)


136
137
138
# File 'lib/onfido/configuration.rb', line 136

def ssl_verify
  @ssl_verify
end

#ssl_verify_modeObject

Note:

Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.

TLS/SSL setting Any ‘OpenSSL::SSL::` constant (see ruby-doc.org/stdlib-2.5.1/libdoc/openssl/rdoc/OpenSSL/SSL.html)



143
144
145
# File 'lib/onfido/configuration.rb', line 143

def ssl_verify_mode
  @ssl_verify_mode
end

#temp_folder_pathString

Defines the temporary folder to store downloaded files (for API endpoints that have file response). Default to use ‘Tempfile`.

Returns:

  • (String)


118
119
120
# File 'lib/onfido/configuration.rb', line 118

def temp_folder_path
  @temp_folder_path
end

#timeoutObject

The time limit for HTTP request in seconds. Default to 0 (never times out).



122
123
124
# File 'lib/onfido/configuration.rb', line 122

def timeout
  @timeout
end

#usernameString

Defines the username used with HTTP basic authentication.

Returns:

  • (String)


64
65
66
# File 'lib/onfido/configuration.rb', line 64

def username
  @username
end

Class Method Details

.defaultObject

The default Configuration object.



210
211
212
# File 'lib/onfido/configuration.rb', line 210

def self.default
  @@default ||= Configuration.new
end

Instance Method Details

#access_token_with_refreshObject

Gets access_token using access_token_getter or uses the static access_token



334
335
336
337
# File 'lib/onfido/configuration.rb', line 334

def access_token_with_refresh
  return access_token if access_token_getter.nil?
  access_token_getter.call
end

#api_key_with_prefix(param_name, param_alias = nil) ⇒ Object

Gets API key (with prefix if set).

Parameters:

  • param_name (String)

    the parameter name of API key auth



323
324
325
326
327
328
329
330
331
# File 'lib/onfido/configuration.rb', line 323

def api_key_with_prefix(param_name, param_alias = nil)
  key = @api_key[param_name]
  key = @api_key.fetch(param_alias, key) unless param_alias.nil?
  if @api_key_prefix[param_name]
    "#{@api_key_prefix[param_name]} #{key}"
  else
    key
  end
end

#api_token=(api_token) ⇒ Object

Raises:

  • (ArgumentError)


245
246
247
248
# File 'lib/onfido/configuration.rb', line 245

def api_token=(api_token)
  raise ArgumentError, 'Cannot set API token when OAuth credentials are already configured' if @oauth_client_id 
  @api_key = {'Token' => "Token token=#{api_token}"}
end

#auth_settingsObject

Returns Auth Settings hash for api client.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/onfido/configuration.rb', line 345

def auth_settings
  if @oauth_client_id && !@oauth_client_id.empty?
    return {
      'Token' =>
        {
          type: 'bearer',
          in: 'header',
          key: 'Authorization',
          value: "Bearer #{fetch_oauth_access_token}"
        },
    }
  end
  {
    'Token' =>
      {
        type: 'api_key',
        in: 'header',
        key: 'Authorization',
        value: api_key_with_prefix('Token')
      },
    'OAuth2ClientCredentials' =>
      {
        type: 'oauth2',
        in: 'header',
        key: 'Authorization',
        value: "Bearer #{access_token_with_refresh}"
      },
  }
end

#base_url(operation = nil) ⇒ Object

Returns base URL for specified operation based on server settings



235
236
237
238
239
240
241
242
243
# File 'lib/onfido/configuration.rb', line 235

def base_url(operation = nil)
  return "#{scheme}://#{[host, base_path].join('/').gsub(/\/+/, '/')}".sub(/\/+\z/, '') if ignore_operation_servers
  if operation_server_settings.key?(operation) then
    index = server_operation_index.fetch(operation, server_index)
    server_url(index.nil? ? 0 : index, server_operation_variables.fetch(operation, server_variables), operation_server_settings[operation])
  else
    server_index.nil? ? "#{scheme}://#{[host, base_path].join('/').gsub(/\/+/, '/')}".sub(/\/+\z/, '') : server_url(server_index, server_variables, nil)
  end
end

#basic_auth_tokenObject

Gets Basic Auth token string



340
341
342
# File 'lib/onfido/configuration.rb', line 340

def basic_auth_token
  'Basic ' + ["#{username}:#{password}"].pack('m').delete("\r\n")
end

#configure {|_self| ... } ⇒ Object

Yields:

  • (_self)

Yield Parameters:



214
215
216
# File 'lib/onfido/configuration.rb', line 214

def configure
  yield(self) if block_given?
end

#configure_connection(conn) ⇒ Object



455
456
457
458
459
# File 'lib/onfido/configuration.rb', line 455

def configure_connection(conn)
  @configure_connection_blocks.each do |block|
    block.call(conn)
  end
end

#configure_faraday_connection(&block) ⇒ Object

Configure Faraday connection directly.

“‘ c.configure_faraday_connection do |conn|

conn.use Faraday::HttpCache, shared_cache: false, logger: logger
conn.response :logger, nil, headers: true, bodies: true, log_level: :debug do |logger|
  logger.filter(/(Authorization: )(.*)/, '\1[REDACTED]')
end

end

c.configure_faraday_connection do |conn|

conn.adapter :typhoeus

end “‘

Parameters:

  • block (Proc)

    ‘#call`able object that takes one arg, the connection



451
452
453
# File 'lib/onfido/configuration.rb', line 451

def configure_faraday_connection(&block)
  @configure_connection_blocks << block
end

#configure_middleware(connection) ⇒ Object

Set up middleware on the connection



498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/onfido/configuration.rb', line 498

def configure_middleware(connection)
  return if @middlewares.empty?

  [:request, :response, :use, :insert, :insert_before, :insert_after, :swap].each do |operation|
    next unless @middlewares.key?(operation)

    @middlewares[operation].each do |key, args, block|
      connection.builder.send(operation, key, *args, &block)
    end
  end

  if @middlewares.key?(:delete)
    @middlewares[:delete].each do |key, _args, _block|
      connection.builder.delete(key)
    end
  end
end

#operation_server_settingsObject



396
397
398
399
# File 'lib/onfido/configuration.rb', line 396

def operation_server_settings
  {
  }
end

#regionObject



250
251
252
# File 'lib/onfido/configuration.rb', line 250

def region()
  REGIONS
end

#region=(region) ⇒ Object



254
255
256
257
# File 'lib/onfido/configuration.rb', line 254

def region=(region)
  @server_index = 0
  server_variables[:region] = region
end

#request(*middleware) ⇒ Object

Adds request middleware to the stack



467
468
469
# File 'lib/onfido/configuration.rb', line 467

def request(*middleware)
  set_faraday_middleware(:request, *middleware)
end

#response(*middleware) ⇒ Object

Adds response middleware to the stack



472
473
474
# File 'lib/onfido/configuration.rb', line 472

def response(*middleware)
  set_faraday_middleware(:response, *middleware)
end

#server_settingsObject

Returns an array of Server setting



376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/onfido/configuration.rb', line 376

def server_settings
  [
    {
      url: "https://api.{region}.onfido.com/v3.6",
      description: "No description provided",
      variables: {
        region: {
            description: "No description provided",
            default_value: "eu",
            enum_values: [
              "eu",
              "us",
              "ca"
            ]
          }
        }
    }
  ]
end

#server_url(index, variables = {}, servers = nil) ⇒ Object

Returns URL based on server settings

Parameters:

  • index

    array index of the server settings

  • variables (defaults to: {})

    hash of variable and the corresponding value



405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
# File 'lib/onfido/configuration.rb', line 405

def server_url(index, variables = {}, servers = nil)
  servers = server_settings if servers == nil

  # check array index out of bound
  if (index.nil? || index < 0 || index >= servers.size)
    fail ArgumentError, "Invalid index #{index} when selecting the server. Must not be nil and must be less than #{servers.size}"
  end

  server = servers[index]
  url = server[:url]

  return url unless server.key? :variables

  # go through variable and assign a value
  server[:variables].each do |name, variable|
    if variables.key?(name)
      if (!server[:variables][name].key?(:enum_values) || server[:variables][name][:enum_values].include?(variables[name]))
        url.gsub! "{" + name.to_s + "}", variables[name]
      else
        fail ArgumentError, "The variable `#{name}` in the server URL has invalid value #{variables[name]}. Must be #{server[:variables][name][:enum_values]}."
      end
    else
      # use default value
      url.gsub! "{" + name.to_s + "}", server[:variables][name][:default_value]
    end
  end

  url
end

#set_faraday_middleware(operation, key, *args, &block) ⇒ Object

Adds Faraday middleware setting information to the stack

Examples:

Use the ‘set_faraday_middleware` method to set middleware information

config.set_faraday_middleware(:request, :retry, max: 3, methods: [:get, :post], retry_statuses: [503])
config.set_faraday_middleware(:response, :logger, nil, { bodies: true, log_level: :debug })
config.set_faraday_middleware(:use, Faraday::HttpCache, store: Rails.cache, shared_cache: false)
config.set_faraday_middleware(:insert, 0, FaradayMiddleware::FollowRedirects, { standards_compliant: true, limit: 1 })
config.set_faraday_middleware(:swap, 0, Faraday::Response::Logger)
config.set_faraday_middleware(:delete, Faraday::Multipart::Middleware)

See Also:



487
488
489
490
491
492
493
494
# File 'lib/onfido/configuration.rb', line 487

def set_faraday_middleware(operation, key, *args, &block)
  unless [:request, :response, :use, :insert, :insert_before, :insert_after, :swap, :delete].include?(operation)
    fail ArgumentError, "Invalid faraday middleware operation #{operation}. Must be" \
                        " :request, :response, :use, :insert, :insert_before, :insert_after, :swap or :delete."
  end

  @middlewares[operation] << [key, args, block]
end

#set_oauth_credentials(client_id, client_secret) ⇒ Object

Sets OAuth2 client credentials for authentication. The client will automatically exchange credentials for an access token and refresh it when expired. This is mutually exclusive with api_token.

Parameters:

  • client_id (String)

    OAuth2 client ID

  • client_secret (String)

    OAuth2 client secret

Raises:

  • (ArgumentError)


269
270
271
272
273
274
275
276
277
278
# File 'lib/onfido/configuration.rb', line 269

def set_oauth_credentials(client_id, client_secret)
  raise ArgumentError, 'OAuth client ID must not be nil or empty' if client_id.nil? || client_id.empty?
  raise ArgumentError, 'OAuth client secret must not be nil or empty' if client_secret.nil? || client_secret.empty?
  raise ArgumentError, 'Cannot set OAuth credentials when API token is already configured' if @api_key&.key?('Token') 

  @oauth_client_id = client_id
  @oauth_client_secret = client_secret
  @oauth_access_token = nil
  @oauth_token_expires_at = nil
end

#use(*middleware) ⇒ Object

Adds middleware to the stack



462
463
464
# File 'lib/onfido/configuration.rb', line 462

def use(*middleware)
  set_faraday_middleware(:use, *middleware)
end