Class: Onfido::DeviceIntelligencePropertiesDevice

Inherits:
Object
  • Object
show all
Defined in:
lib/onfido/models/device_intelligence_properties_device.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DeviceIntelligencePropertiesDevice

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 151

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Onfido::DeviceIntelligencePropertiesDevice` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Onfido::DeviceIntelligencePropertiesDevice`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'sdk_version')
    self.sdk_version = attributes[:'sdk_version']
  end

  if attributes.key?(:'sdk_source')
    self.sdk_source = attributes[:'sdk_source']
  end

  if attributes.key?(:'authentication_type')
    self.authentication_type = attributes[:'authentication_type']
  end

  if attributes.key?(:'raw_model')
    self.raw_model = attributes[:'raw_model']
  end

  if attributes.key?(:'os')
    self.os = attributes[:'os']
  end

  if attributes.key?(:'browser')
    self.browser = attributes[:'browser']
  end

  if attributes.key?(:'emulator')
    self.emulator = attributes[:'emulator']
  end

  if attributes.key?(:'randomized_device')
    self.randomized_device = attributes[:'randomized_device']
  end

  if attributes.key?(:'number_of_ip_reuse_reports')
    self.number_of_ip_reuse_reports = attributes[:'number_of_ip_reuse_reports']
  end

  if attributes.key?(:'number_of_suspected_ip_reuse_reports')
    self.number_of_suspected_ip_reuse_reports = attributes[:'number_of_suspected_ip_reuse_reports']
  end

  if attributes.key?(:'fake_network_request')
    self.fake_network_request = attributes[:'fake_network_request']
  end

  if attributes.key?(:'ip_reputation')
    self.ip_reputation = attributes[:'ip_reputation']
  end

  if attributes.key?(:'device_fingerprint_reuse')
    self.device_fingerprint_reuse = attributes[:'device_fingerprint_reuse']
  end

  if attributes.key?(:'single_device_used')
    self.single_device_used = attributes[:'single_device_used']
  end

  if attributes.key?(:'document_capture')
    self.document_capture = attributes[:'document_capture']
  end

  if attributes.key?(:'biometric_capture')
    self.biometric_capture = attributes[:'biometric_capture']
  end
end

Instance Attribute Details

#authentication_typeObject

The token used to authenticate the request.



25
26
27
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 25

def authentication_type
  @authentication_type
end

#biometric_captureObject

Whether the biometric media were live captured from the device camera.



64
65
66
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 64

def biometric_capture
  @biometric_capture
end

#browserObject

The browser name reported by the browser’s user agent.



34
35
36
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 34

def browser
  @browser
end

#device_fingerprint_reuseObject

The number of times the device was used to create a report for a new applicant. A value greater than 1 indicates potential device reuse.



55
56
57
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 55

def device_fingerprint_reuse
  @device_fingerprint_reuse
end

#document_captureObject

Whether the document media were live captured from the device camera.



61
62
63
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 61

def document_capture
  @document_capture
end

#emulatorObject

Whether the device is an emulator.



37
38
39
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 37

def emulator
  @emulator
end

#fake_network_requestObject

Whether device is using stolen security tokens to send the network information.



49
50
51
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 49

def fake_network_request
  @fake_network_request
end

#ip_reputationObject

Whether there is highly suspicious traffic related to the IP address. The risk depends on the overall ratio of clear checks on a given IP.



52
53
54
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 52

def ip_reputation
  @ip_reputation
end

#number_of_ip_reuse_reportsObject

Counts the number of distinct document reports submitted in the last 24 hours that are associated with the applicant’s IP address.



43
44
45
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 43

def number_of_ip_reuse_reports
  @number_of_ip_reuse_reports
end

#number_of_suspected_ip_reuse_reportsObject

Counts the number of distinct document reports from the last 24 hours associated with the applicant’s IP address that have a result of suspected and other document integrity or authenticity signals have been flagged.



46
47
48
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 46

def number_of_suspected_ip_reuse_reports
  @number_of_suspected_ip_reuse_reports
end

#osObject

The operating system of the device. The value came from manufacturer implementation (for Android and iOS) or browser’s user agent (for Web).



31
32
33
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 31

def os
  @os
end

#randomized_deviceObject

Whether the device is providing false randomized device and network information.



40
41
42
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 40

def randomized_device
  @randomized_device
end

#raw_modelObject

The model as set by the phone manufacturer (for Android and iOS) or the browser manufacturer (for Web). The model can be presented in name or number form depending on each manufacturer implementation.



28
29
30
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 28

def raw_model
  @raw_model
end

#sdk_sourceObject

The SDK used to upload the media.



22
23
24
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 22

def sdk_source
  @sdk_source
end

#sdk_versionObject

The SDK version that was used.



19
20
21
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 19

def sdk_version
  @sdk_version
end

#single_device_usedObject

Whether the document or biometric media were uploaded from a single device.



58
59
60
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 58

def single_device_used
  @single_device_used
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 367

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Onfido.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



111
112
113
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 111

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



116
117
118
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 116

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 89

def self.attribute_map
  {
    :'sdk_version' => :'sdk_version',
    :'sdk_source' => :'sdk_source',
    :'authentication_type' => :'authentication_type',
    :'raw_model' => :'raw_model',
    :'os' => :'os',
    :'browser' => :'browser',
    :'emulator' => :'emulator',
    :'randomized_device' => :'randomized_device',
    :'number_of_ip_reuse_reports' => :'number_of_ip_reuse_reports',
    :'number_of_suspected_ip_reuse_reports' => :'number_of_suspected_ip_reuse_reports',
    :'fake_network_request' => :'fake_network_request',
    :'ip_reputation' => :'ip_reputation',
    :'device_fingerprint_reuse' => :'device_fingerprint_reuse',
    :'single_device_used' => :'single_device_used',
    :'document_capture' => :'document_capture',
    :'biometric_capture' => :'biometric_capture'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 343

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



143
144
145
146
147
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 143

def self.openapi_nullable
  Set.new([
    :'single_device_used',
  ])
end

.openapi_typesObject

Attribute type mapping.



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 121

def self.openapi_types
  {
    :'sdk_version' => :'String',
    :'sdk_source' => :'String',
    :'authentication_type' => :'String',
    :'raw_model' => :'String',
    :'os' => :'String',
    :'browser' => :'String',
    :'emulator' => :'Boolean',
    :'randomized_device' => :'Boolean',
    :'number_of_ip_reuse_reports' => :'Float',
    :'number_of_suspected_ip_reuse_reports' => :'Float',
    :'fake_network_request' => :'Boolean',
    :'ip_reputation' => :'String',
    :'device_fingerprint_reuse' => :'Float',
    :'single_device_used' => :'Boolean',
    :'document_capture' => :'String',
    :'biometric_capture' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 307

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      sdk_version == o.sdk_version &&
      sdk_source == o.sdk_source &&
      authentication_type == o.authentication_type &&
      raw_model == o.raw_model &&
      os == o.os &&
      browser == o.browser &&
      emulator == o.emulator &&
      randomized_device == o.randomized_device &&
      number_of_ip_reuse_reports == o.number_of_ip_reuse_reports &&
      number_of_suspected_ip_reuse_reports == o.number_of_suspected_ip_reuse_reports &&
      fake_network_request == o.fake_network_request &&
      ip_reputation == o.ip_reputation &&
      device_fingerprint_reuse == o.device_fingerprint_reuse &&
      single_device_used == o.single_device_used &&
      document_capture == o.document_capture &&
      biometric_capture == o.biometric_capture
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 438

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


330
331
332
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 330

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



336
337
338
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 336

def hash
  [sdk_version, sdk_source, authentication_type, raw_model, os, browser, emulator, randomized_device, number_of_ip_reuse_reports, number_of_suspected_ip_reuse_reports, fake_network_request, ip_reputation, device_fingerprint_reuse, single_device_used, document_capture, biometric_capture].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



232
233
234
235
236
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 232

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



414
415
416
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 414

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



420
421
422
423
424
425
426
427
428
429
430
431
432
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 420

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



408
409
410
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 408

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/onfido/models/device_intelligence_properties_device.rb', line 240

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  sdk_source_validator = EnumAttributeValidator.new('String', ["onfido-android-sdk", "onfido-ios-sdk", "onfido-web-sdk", "unknown_default_open_api"])
  return false unless sdk_source_validator.valid?(@sdk_source)
  authentication_type_validator = EnumAttributeValidator.new('String', ["sdk_token", "mobile_token", "api_token", "unknown_default_open_api"])
  return false unless authentication_type_validator.valid?(@authentication_type)
  ip_reputation_validator = EnumAttributeValidator.new('String', ["NOT_ENOUGH_DATA", "HIGH_RISK", "LOW_RISK", "unknown_default_open_api"])
  return false unless ip_reputation_validator.valid?(@ip_reputation)
  document_capture_validator = EnumAttributeValidator.new('String', ["live", "unknown_method", "unknown_default_open_api"])
  return false unless document_capture_validator.valid?(@document_capture)
  biometric_capture_validator = EnumAttributeValidator.new('String', ["live", "unknown_method", "unknown_default_open_api"])
  return false unless biometric_capture_validator.valid?(@biometric_capture)
  true
end