Class: Onfido::Document
- Inherits:
-
Object
- Object
- Onfido::Document
- Defined in:
- lib/onfido/models/document.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#applicant_id ⇒ Object
The ID of the applicant whose document is being uploaded.
-
#created_at ⇒ Object
The date and time at which the document was uploaded.
-
#download_href ⇒ Object
The uri that can be used to download the document.
-
#file_name ⇒ Object
The name of the uploaded file.
-
#file_size ⇒ Object
The size of the file in bytes.
-
#file_type ⇒ Object
The file type of the uploaded file.
-
#href ⇒ Object
The uri of this resource.
-
#id ⇒ Object
The unique identifier for the document.
-
#issuing_country ⇒ Object
The issuing country of the document, a 3-letter ISO code.
-
#side ⇒ Object
The side of the document, if applicable.
-
#type ⇒ Object
The type of document.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Document
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Document
Initializes the object
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/onfido/models/document.rb', line 133 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Onfido::Document` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Onfido::Document`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'file_type') self.file_type = attributes[:'file_type'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'side') self.side = attributes[:'side'] end if attributes.key?(:'issuing_country') self.issuing_country = attributes[:'issuing_country'] end if attributes.key?(:'applicant_id') self.applicant_id = attributes[:'applicant_id'] end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'href') self.href = attributes[:'href'] end if attributes.key?(:'download_href') self.download_href = attributes[:'download_href'] end if attributes.key?(:'file_name') self.file_name = attributes[:'file_name'] end if attributes.key?(:'file_size') self.file_size = attributes[:'file_size'] end end |
Instance Attribute Details
#applicant_id ⇒ Object
The ID of the applicant whose document is being uploaded.
31 32 33 |
# File 'lib/onfido/models/document.rb', line 31 def applicant_id @applicant_id end |
#created_at ⇒ Object
The date and time at which the document was uploaded
37 38 39 |
# File 'lib/onfido/models/document.rb', line 37 def created_at @created_at end |
#download_href ⇒ Object
The uri that can be used to download the document
43 44 45 |
# File 'lib/onfido/models/document.rb', line 43 def download_href @download_href end |
#file_name ⇒ Object
The name of the uploaded file
46 47 48 |
# File 'lib/onfido/models/document.rb', line 46 def file_name @file_name end |
#file_size ⇒ Object
The size of the file in bytes
49 50 51 |
# File 'lib/onfido/models/document.rb', line 49 def file_size @file_size end |
#file_type ⇒ Object
The file type of the uploaded file
19 20 21 |
# File 'lib/onfido/models/document.rb', line 19 def file_type @file_type end |
#href ⇒ Object
The uri of this resource
40 41 42 |
# File 'lib/onfido/models/document.rb', line 40 def href @href end |
#id ⇒ Object
The unique identifier for the document
34 35 36 |
# File 'lib/onfido/models/document.rb', line 34 def id @id end |
#issuing_country ⇒ Object
The issuing country of the document, a 3-letter ISO code.
28 29 30 |
# File 'lib/onfido/models/document.rb', line 28 def issuing_country @issuing_country end |
#side ⇒ Object
The side of the document, if applicable. The possible values are front and back
25 26 27 |
# File 'lib/onfido/models/document.rb', line 25 def side @side end |
#type ⇒ Object
The type of document
22 23 24 |
# File 'lib/onfido/models/document.rb', line 22 def type @type end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/onfido/models/document.rb', line 293 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Onfido.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
91 92 93 |
# File 'lib/onfido/models/document.rb', line 91 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
96 97 98 |
# File 'lib/onfido/models/document.rb', line 96 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/onfido/models/document.rb', line 74 def self.attribute_map { :'file_type' => :'file_type', :'type' => :'type', :'side' => :'side', :'issuing_country' => :'issuing_country', :'applicant_id' => :'applicant_id', :'id' => :'id', :'created_at' => :'created_at', :'href' => :'href', :'download_href' => :'download_href', :'file_name' => :'file_name', :'file_size' => :'file_size' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/onfido/models/document.rb', line 269 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
124 125 126 127 128 129 |
# File 'lib/onfido/models/document.rb', line 124 def self.openapi_all_of [ :'DocumentResponse', :'DocumentShared' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
118 119 120 121 |
# File 'lib/onfido/models/document.rb', line 118 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/onfido/models/document.rb', line 101 def self.openapi_types { :'file_type' => :'String', :'type' => :'DocumentTypes', :'side' => :'String', :'issuing_country' => :'CountryCodes', :'applicant_id' => :'String', :'id' => :'String', :'created_at' => :'Time', :'href' => :'String', :'download_href' => :'String', :'file_name' => :'String', :'file_size' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/onfido/models/document.rb', line 238 def ==(o) return true if self.equal?(o) self.class == o.class && file_type == o.file_type && type == o.type && side == o.side && issuing_country == o.issuing_country && applicant_id == o.applicant_id && id == o.id && created_at == o.created_at && href == o.href && download_href == o.download_href && file_name == o.file_name && file_size == o.file_size end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/onfido/models/document.rb', line 364 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
256 257 258 |
# File 'lib/onfido/models/document.rb', line 256 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
262 263 264 |
# File 'lib/onfido/models/document.rb', line 262 def hash [file_type, type, side, issuing_country, applicant_id, id, created_at, href, download_href, file_name, file_size].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
196 197 198 199 200 201 202 203 204 |
# File 'lib/onfido/models/document.rb', line 196 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
340 341 342 |
# File 'lib/onfido/models/document.rb', line 340 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/onfido/models/document.rb', line 346 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
334 335 336 |
# File 'lib/onfido/models/document.rb', line 334 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
208 209 210 211 212 213 214 |
# File 'lib/onfido/models/document.rb', line 208 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' side_validator = EnumAttributeValidator.new('String', ["front", "back", "unknown_default_open_api"]) return false unless side_validator.valid?(@side) return false if @id.nil? true end |