Class: Onfido::FacialSimilarityPhotoReport

Inherits:
Object
  • Object
show all
Defined in:
lib/onfido/models/facial_similarity_photo_report.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FacialSimilarityPhotoReport

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 147

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Onfido::FacialSimilarityPhotoReport` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Onfido::FacialSimilarityPhotoReport`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'href')
    self.href = attributes[:'href']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'result')
    self.result = attributes[:'result']
  end

  if attributes.key?(:'sub_result')
    self.sub_result = attributes[:'sub_result']
  end

  if attributes.key?(:'check_id')
    self.check_id = attributes[:'check_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'documents')
    if (value = attributes[:'documents']).is_a?(Array)
      self.documents = value
    end
  end

  if attributes.key?(:'live_photos')
    if (value = attributes[:'live_photos']).is_a?(Array)
      self.live_photos = value
    end
  end

  if attributes.key?(:'live_videos')
    if (value = attributes[:'live_videos']).is_a?(Array)
      self.live_videos = value
    end
  end

  if attributes.key?(:'motion_captures')
    if (value = attributes[:'motion_captures']).is_a?(Array)
      self.motion_captures = value
    end
  end

  if attributes.key?(:'id_photos')
    if (value = attributes[:'id_photos']).is_a?(Array)
      self.id_photos = value
    end
  end

  if attributes.key?(:'breakdown')
    self.breakdown = attributes[:'breakdown']
  end

  if attributes.key?(:'properties')
    self.properties = attributes[:'properties']
  end
end

Instance Attribute Details

#breakdownObject

Returns the value of attribute breakdown.



53
54
55
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 53

def breakdown
  @breakdown
end

#check_idObject

The ID of the check to which the report belongs. Read-only.



34
35
36
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 34

def check_id
  @check_id
end

#created_atObject

The date and time at which the report was first initiated. Read-only.



22
23
24
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 22

def created_at
  @created_at
end

#documentsObject

Array of objects with document ids that were used in the Onfido engine.



39
40
41
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 39

def documents
  @documents
end

#hrefObject

The API endpoint to retrieve the report. Read-only.



25
26
27
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 25

def href
  @href
end

#idObject

The unique identifier for the report. Read-only.



19
20
21
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 19

def id
  @id
end

#id_photosObject

Array of objects with id photo ids that were used in the Onfido engine.



51
52
53
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 51

def id_photos
  @id_photos
end

#live_photosObject

Array of objects with live photo ids that were used in the Onfido engine.



42
43
44
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 42

def live_photos
  @live_photos
end

#live_videosObject

Array of objects with live video ids that were used in the Onfido engine.



45
46
47
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 45

def live_videos
  @live_videos
end

#motion_capturesObject

Array of objects with motion capture ids that were used in the Onfido engine.



48
49
50
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 48

def motion_captures
  @motion_captures
end

#nameObject

Returns the value of attribute name.



36
37
38
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 36

def name
  @name
end

#propertiesObject

Returns the value of attribute properties.



55
56
57
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 55

def properties
  @properties
end

#resultObject

Returns the value of attribute result.



29
30
31
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 29

def result
  @result
end

#statusObject

Returns the value of attribute status.



27
28
29
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 27

def status
  @status
end

#sub_resultObject

Returns the value of attribute sub_result.



31
32
33
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 31

def sub_result
  @sub_result
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 342

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Onfido.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



101
102
103
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 101

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



106
107
108
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 106

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 80

def self.attribute_map
  {
    :'id' => :'id',
    :'created_at' => :'created_at',
    :'href' => :'href',
    :'status' => :'status',
    :'result' => :'result',
    :'sub_result' => :'sub_result',
    :'check_id' => :'check_id',
    :'name' => :'name',
    :'documents' => :'documents',
    :'live_photos' => :'live_photos',
    :'live_videos' => :'live_videos',
    :'motion_captures' => :'motion_captures',
    :'id_photos' => :'id_photos',
    :'breakdown' => :'breakdown',
    :'properties' => :'properties'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 318

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



138
139
140
141
142
143
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 138

def self.openapi_all_of
  [
  :'FacialSimilarityReportShared',
  :'ReportShared'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



132
133
134
135
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 132

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 111

def self.openapi_types
  {
    :'id' => :'String',
    :'created_at' => :'Time',
    :'href' => :'String',
    :'status' => :'ReportStatus',
    :'result' => :'ReportResult',
    :'sub_result' => :'ReportSubResult',
    :'check_id' => :'String',
    :'name' => :'ReportName',
    :'documents' => :'Array<ReportDocument>',
    :'live_photos' => :'Array<FacialSimilarityReportMedia>',
    :'live_videos' => :'Array<FacialSimilarityReportMedia>',
    :'motion_captures' => :'Array<FacialSimilarityReportMedia>',
    :'id_photos' => :'Array<FacialSimilarityReportMedia>',
    :'breakdown' => :'FacialSimilarityPhotoBreakdown',
    :'properties' => :'FacialSimilarityPhotoProperties'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 283

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      created_at == o.created_at &&
      href == o.href &&
      status == o.status &&
      result == o.result &&
      sub_result == o.sub_result &&
      check_id == o.check_id &&
      name == o.name &&
      documents == o.documents &&
      live_photos == o.live_photos &&
      live_videos == o.live_videos &&
      motion_captures == o.motion_captures &&
      id_photos == o.id_photos &&
      breakdown == o.breakdown &&
      properties == o.properties
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 413

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


305
306
307
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 305

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



311
312
313
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 311

def hash
  [id, created_at, href, status, result, sub_result, check_id, name, documents, live_photos, live_videos, motion_captures, id_photos, breakdown, properties].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 238

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



389
390
391
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 389

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 395

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



383
384
385
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 383

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



254
255
256
257
258
259
# File 'lib/onfido/models/facial_similarity_photo_report.rb', line 254

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  true
end