Class: Onfido::RepeatAttemptsListRepeatAttemptsInner
- Inherits:
-
Object
- Object
- Onfido::RepeatAttemptsListRepeatAttemptsInner
- Defined in:
- lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#applicant_id ⇒ Object
The unique identifier of the applicant for the matching Document report.
-
#completed_at ⇒ Object
When the matching report was completed.
-
#created_at ⇒ Object
When the matching report was created.
-
#date_of_birth ⇒ Object
Whether the dates of birth are exactly the same or are different.
-
#names ⇒ Object
Whether the names are exactly the same or are different.
-
#report_id ⇒ Object
The unique identifier of the matching Document report.
-
#result ⇒ Object
The report result of this attempt.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RepeatAttemptsListRepeatAttemptsInner
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ RepeatAttemptsListRepeatAttemptsInner
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `Onfido::RepeatAttemptsListRepeatAttemptsInner` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `Onfido::RepeatAttemptsListRepeatAttemptsInner`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'report_id') self.report_id = attributes[:'report_id'] end if attributes.key?(:'applicant_id') self.applicant_id = attributes[:'applicant_id'] end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end if attributes.key?(:'names') self.names = attributes[:'names'] end if attributes.key?(:'result') self.result = attributes[:'result'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'completed_at') self.completed_at = attributes[:'completed_at'] end end |
Instance Attribute Details
#applicant_id ⇒ Object
The unique identifier of the applicant for the matching Document report.
22 23 24 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 22 def applicant_id @applicant_id end |
#completed_at ⇒ Object
When the matching report was completed.
37 38 39 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 37 def completed_at @completed_at end |
#created_at ⇒ Object
When the matching report was created.
34 35 36 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 34 def created_at @created_at end |
#date_of_birth ⇒ Object
Whether the dates of birth are exactly the same or are different.
25 26 27 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 25 def date_of_birth @date_of_birth end |
#names ⇒ Object
Whether the names are exactly the same or are different.
28 29 30 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 28 def names @names end |
#report_id ⇒ Object
The unique identifier of the matching Document report.
19 20 21 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 19 def report_id @report_id end |
#result ⇒ Object
The report result of this attempt.
31 32 33 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 31 def result @result end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 252 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = Onfido.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 62 def self.attribute_map { :'report_id' => :'report_id', :'applicant_id' => :'applicant_id', :'date_of_birth' => :'date_of_birth', :'names' => :'names', :'result' => :'result', :'created_at' => :'created_at', :'completed_at' => :'completed_at' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 228 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 85 def self.openapi_types { :'report_id' => :'String', :'applicant_id' => :'String', :'date_of_birth' => :'String', :'names' => :'String', :'result' => :'String', :'created_at' => :'Time', :'completed_at' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 201 def ==(o) return true if self.equal?(o) self.class == o.class && report_id == o.report_id && applicant_id == o.applicant_id && date_of_birth == o.date_of_birth && names == o.names && result == o.result && created_at == o.created_at && completed_at == o.completed_at end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 323 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
215 216 217 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 215 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
221 222 223 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 221 def hash [report_id, applicant_id, date_of_birth, names, result, created_at, completed_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
150 151 152 153 154 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 150 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
299 300 301 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 299 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 305 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
293 294 295 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 293 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
158 159 160 161 162 163 164 165 166 167 |
# File 'lib/onfido/models/repeat_attempts_list_repeat_attempts_inner.rb', line 158 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' date_of_birth_validator = EnumAttributeValidator.new('String', ["match", "mismatch", "unknown_default_open_api"]) return false unless date_of_birth_validator.valid?(@date_of_birth) names_validator = EnumAttributeValidator.new('String', ["match", "mismatch", "unknown_default_open_api"]) return false unless names_validator.valid?(@names) result_validator = EnumAttributeValidator.new('String', ["clear", "consider", "unknown_default_open_api"]) return false unless result_validator.valid?(@result) true end |