Class: Onfido::Webhook

Inherits:
Object
  • Object
show all
Defined in:
lib/onfido/models/webhook.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Webhook

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/onfido/models/webhook.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Onfido::Webhook` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Onfido::Webhook`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'events')
    if (value = attributes[:'events']).is_a?(Array)
      self.events = value
    end
  end

  if attributes.key?(:'environments')
    if (value = attributes[:'environments']).is_a?(Array)
      self.environments = value
    end
  end

  if attributes.key?(:'payload_version')
    self.payload_version = attributes[:'payload_version']
  end

  if attributes.key?(:'oauth_enabled')
    self.oauth_enabled = attributes[:'oauth_enabled']
  end

  if attributes.key?(:'oauth_server_url')
    self.oauth_server_url = attributes[:'oauth_server_url']
  end

  if attributes.key?(:'oauth_server_client_id')
    self.oauth_server_client_id = attributes[:'oauth_server_client_id']
  end

  if attributes.key?(:'oauth_server_client_secret')
    self.oauth_server_client_secret = attributes[:'oauth_server_client_secret']
  end

  if attributes.key?(:'oauth_server_scope')
    self.oauth_server_scope = attributes[:'oauth_server_scope']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'href')
    self.href = attributes[:'href']
  end
end

Instance Attribute Details

#enabledObject

Determine if the webhook is active.



19
20
21
# File 'lib/onfido/models/webhook.rb', line 19

def enabled
  @enabled
end

#environmentsObject

The environments from which the webhook will receive events. Allowed values are “sandbox” and “live”. If the environments parameter is omitted the webhook will receive events from both environments.



25
26
27
# File 'lib/onfido/models/webhook.rb', line 25

def environments
  @environments
end

#eventsObject

The events that will be published to the webhook. If the events parameter is omitted all the events will be subscribed.



22
23
24
# File 'lib/onfido/models/webhook.rb', line 22

def events
  @events
end

#hrefObject

The API endpoint to retrieve the webhook.



55
56
57
# File 'lib/onfido/models/webhook.rb', line 55

def href
  @href
end

#idObject

The unique identifier of the webhook.



46
47
48
# File 'lib/onfido/models/webhook.rb', line 46

def id
  @id
end

#oauth_enabledObject

Determines if the webhook will fetch OAuth access tokens to send in the Authorization header.



31
32
33
# File 'lib/onfido/models/webhook.rb', line 31

def oauth_enabled
  @oauth_enabled
end

#oauth_server_client_idObject

The client id to authenticate the client credentials grant.



37
38
39
# File 'lib/onfido/models/webhook.rb', line 37

def oauth_server_client_id
  @oauth_server_client_id
end

#oauth_server_client_secretObject

The client secret to authenticate the client credentials grant.



40
41
42
# File 'lib/onfido/models/webhook.rb', line 40

def oauth_server_client_secret
  @oauth_server_client_secret
end

#oauth_server_scopeObject

The scopes to be sent when requesting the access token.



43
44
45
# File 'lib/onfido/models/webhook.rb', line 43

def oauth_server_scope
  @oauth_server_scope
end

#oauth_server_urlObject

The url to fetch the OAuth access token using client credentials grant.



34
35
36
# File 'lib/onfido/models/webhook.rb', line 34

def oauth_server_url
  @oauth_server_url
end

#payload_versionObject

Webhook version used to control the payload object when sending webhooks.



28
29
30
# File 'lib/onfido/models/webhook.rb', line 28

def payload_version
  @payload_version
end

#tokenObject

Webhook secret token used to sign the webhook’s payload.



52
53
54
# File 'lib/onfido/models/webhook.rb', line 52

def token
  @token
end

#urlObject

The url that will listen to notifications (must be https).



49
50
51
# File 'lib/onfido/models/webhook.rb', line 49

def url
  @url
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/onfido/models/webhook.rb', line 283

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Onfido.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



77
78
79
# File 'lib/onfido/models/webhook.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/onfido/models/webhook.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/onfido/models/webhook.rb', line 58

def self.attribute_map
  {
    :'enabled' => :'enabled',
    :'events' => :'events',
    :'environments' => :'environments',
    :'payload_version' => :'payload_version',
    :'oauth_enabled' => :'oauth_enabled',
    :'oauth_server_url' => :'oauth_server_url',
    :'oauth_server_client_id' => :'oauth_server_client_id',
    :'oauth_server_client_secret' => :'oauth_server_client_secret',
    :'oauth_server_scope' => :'oauth_server_scope',
    :'id' => :'id',
    :'url' => :'url',
    :'token' => :'token',
    :'href' => :'href'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/onfido/models/webhook.rb', line 259

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



112
113
114
115
116
117
# File 'lib/onfido/models/webhook.rb', line 112

def self.openapi_all_of
  [
  :'WebhookResponse',
  :'WebhookShared'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



106
107
108
109
# File 'lib/onfido/models/webhook.rb', line 106

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/onfido/models/webhook.rb', line 87

def self.openapi_types
  {
    :'enabled' => :'Boolean',
    :'events' => :'Array<WebhookEventType>',
    :'environments' => :'Array<String>',
    :'payload_version' => :'Integer',
    :'oauth_enabled' => :'Boolean',
    :'oauth_server_url' => :'String',
    :'oauth_server_client_id' => :'String',
    :'oauth_server_client_secret' => :'String',
    :'oauth_server_scope' => :'String',
    :'id' => :'String',
    :'url' => :'String',
    :'token' => :'String',
    :'href' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/onfido/models/webhook.rb', line 226

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      enabled == o.enabled &&
      events == o.events &&
      environments == o.environments &&
      payload_version == o.payload_version &&
      oauth_enabled == o.oauth_enabled &&
      oauth_server_url == o.oauth_server_url &&
      oauth_server_client_id == o.oauth_server_client_id &&
      oauth_server_client_secret == o.oauth_server_client_secret &&
      oauth_server_scope == o.oauth_server_scope &&
      id == o.id &&
      url == o.url &&
      token == o.token &&
      href == o.href
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/onfido/models/webhook.rb', line 354

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


246
247
248
# File 'lib/onfido/models/webhook.rb', line 246

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



252
253
254
# File 'lib/onfido/models/webhook.rb', line 252

def hash
  [enabled, events, environments, payload_version, oauth_enabled, oauth_server_url, oauth_server_client_id, oauth_server_client_secret, oauth_server_scope, id, url, token, href].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



196
197
198
199
200
201
202
203
204
# File 'lib/onfido/models/webhook.rb', line 196

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



330
331
332
# File 'lib/onfido/models/webhook.rb', line 330

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/onfido/models/webhook.rb', line 336

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



324
325
326
# File 'lib/onfido/models/webhook.rb', line 324

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



208
209
210
211
212
# File 'lib/onfido/models/webhook.rb', line 208

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  true
end