Class: Onfido::WorkflowRun

Inherits:
Object
  • Object
show all
Defined in:
lib/onfido/models/workflow_run.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ WorkflowRun

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/onfido/models/workflow_run.rb', line 155

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `Onfido::WorkflowRun` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `Onfido::WorkflowRun`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'applicant_id')
    self.applicant_id = attributes[:'applicant_id']
  else
    self.applicant_id = nil
  end

  if attributes.key?(:'workflow_id')
    self.workflow_id = attributes[:'workflow_id']
  else
    self.workflow_id = nil
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'customer_user_id')
    self.customer_user_id = attributes[:'customer_user_id']
  end

  if attributes.key?(:'link')
    self.link = attributes[:'link']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'workflow_version_id')
    self.workflow_version_id = attributes[:'workflow_version_id']
  end

  if attributes.key?(:'dashboard_url')
    self.dashboard_url = attributes[:'dashboard_url']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'output')
    self.output = attributes[:'output']
  end

  if attributes.key?(:'reasons')
    if (value = attributes[:'reasons']).is_a?(Array)
      self.reasons = value
    end
  end

  if attributes.key?(:'error')
    self.error = attributes[:'error']
  end

  if attributes.key?(:'sdk_token')
    self.sdk_token = attributes[:'sdk_token']
  end
end

Instance Attribute Details

#applicant_idObject

The unique identifier for the Applicant.



19
20
21
# File 'lib/onfido/models/workflow_run.rb', line 19

def applicant_id
  @applicant_id
end

#created_atObject

The date and time when the Workflow Run was created.



34
35
36
# File 'lib/onfido/models/workflow_run.rb', line 34

def created_at
  @created_at
end

#customer_user_idObject

Customer-provided user identifier.



28
29
30
# File 'lib/onfido/models/workflow_run.rb', line 28

def customer_user_id
  @customer_user_id
end

#dashboard_urlObject

The URL for viewing the Workflow Run results on your Onfido Dashboard.



46
47
48
# File 'lib/onfido/models/workflow_run.rb', line 46

def dashboard_url
  @dashboard_url
end

#errorObject

Error object. Only set when the Workflow Run status is ‘error’.



58
59
60
# File 'lib/onfido/models/workflow_run.rb', line 58

def error
  @error
end

#idObject

The unique identifier for the Workflow Run.



40
41
42
# File 'lib/onfido/models/workflow_run.rb', line 40

def id
  @id
end

Object for the configuration of the Workflow Run link.



31
32
33
# File 'lib/onfido/models/workflow_run.rb', line 31

def link
  @link
end

#outputObject

Output object contains all of the properties configured on the Workflow version.



52
53
54
# File 'lib/onfido/models/workflow_run.rb', line 52

def output
  @output
end

#reasonsObject

The reasons the Workflow Run outcome was reached. Configurable when creating the Workflow version.



55
56
57
# File 'lib/onfido/models/workflow_run.rb', line 55

def reasons
  @reasons
end

#sdk_tokenObject

Client token to use when loading this workflow run in the Onfido SDK.



61
62
63
# File 'lib/onfido/models/workflow_run.rb', line 61

def sdk_token
  @sdk_token
end

#statusObject

The status of the Workflow Run.



49
50
51
# File 'lib/onfido/models/workflow_run.rb', line 49

def status
  @status
end

#tagsObject

Tags or labels assigned to the workflow run.



25
26
27
# File 'lib/onfido/models/workflow_run.rb', line 25

def tags
  @tags
end

#updated_atObject

The date and time when the Workflow Run was last updated.



37
38
39
# File 'lib/onfido/models/workflow_run.rb', line 37

def updated_at
  @updated_at
end

#workflow_idObject

The unique identifier for the Workflow.



22
23
24
# File 'lib/onfido/models/workflow_run.rb', line 22

def workflow_id
  @workflow_id
end

#workflow_version_idObject

The identifier for the Workflow version.



43
44
45
# File 'lib/onfido/models/workflow_run.rb', line 43

def workflow_version_id
  @workflow_version_id
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
# File 'lib/onfido/models/workflow_run.rb', line 395

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = Onfido.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



107
108
109
# File 'lib/onfido/models/workflow_run.rb', line 107

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



112
113
114
# File 'lib/onfido/models/workflow_run.rb', line 112

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/onfido/models/workflow_run.rb', line 86

def self.attribute_map
  {
    :'applicant_id' => :'applicant_id',
    :'workflow_id' => :'workflow_id',
    :'tags' => :'tags',
    :'customer_user_id' => :'customer_user_id',
    :'link' => :'link',
    :'created_at' => :'created_at',
    :'updated_at' => :'updated_at',
    :'id' => :'id',
    :'workflow_version_id' => :'workflow_version_id',
    :'dashboard_url' => :'dashboard_url',
    :'status' => :'status',
    :'output' => :'output',
    :'reasons' => :'reasons',
    :'error' => :'error',
    :'sdk_token' => :'sdk_token'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/onfido/models/workflow_run.rb', line 371

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_all_ofObject

List of class defined in allOf (OpenAPI v3)



146
147
148
149
150
151
# File 'lib/onfido/models/workflow_run.rb', line 146

def self.openapi_all_of
  [
  :'WorkflowRunResponse',
  :'WorkflowRunShared'
  ]
end

.openapi_nullableObject

List of attributes with nullable: true



138
139
140
141
142
143
# File 'lib/onfido/models/workflow_run.rb', line 138

def self.openapi_nullable
  Set.new([
    :'tags',
    :'sdk_token'
  ])
end

.openapi_typesObject

Attribute type mapping.



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/onfido/models/workflow_run.rb', line 117

def self.openapi_types
  {
    :'applicant_id' => :'String',
    :'workflow_id' => :'String',
    :'tags' => :'Array<String>',
    :'customer_user_id' => :'String',
    :'link' => :'WorkflowRunLink',
    :'created_at' => :'Time',
    :'updated_at' => :'Time',
    :'id' => :'String',
    :'workflow_version_id' => :'Integer',
    :'dashboard_url' => :'String',
    :'status' => :'WorkflowRunStatus',
    :'output' => :'Object',
    :'reasons' => :'Array<String>',
    :'error' => :'WorkflowRunError',
    :'sdk_token' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/onfido/models/workflow_run.rb', line 336

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      applicant_id == o.applicant_id &&
      workflow_id == o.workflow_id &&
      tags == o.tags &&
      customer_user_id == o.customer_user_id &&
      link == o.link &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      id == o.id &&
      workflow_version_id == o.workflow_version_id &&
      dashboard_url == o.dashboard_url &&
      status == o.status &&
      output == o.output &&
      reasons == o.reasons &&
      error == o.error &&
      sdk_token == o.sdk_token
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'lib/onfido/models/workflow_run.rb', line 466

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


358
359
360
# File 'lib/onfido/models/workflow_run.rb', line 358

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



364
365
366
# File 'lib/onfido/models/workflow_run.rb', line 364

def hash
  [applicant_id, workflow_id, tags, customer_user_id, link, created_at, updated_at, id, workflow_version_id, dashboard_url, status, output, reasons, error, sdk_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/onfido/models/workflow_run.rb', line 242

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @applicant_id.nil?
    invalid_properties.push('invalid value for "applicant_id", applicant_id cannot be nil.')
  end

  if @workflow_id.nil?
    invalid_properties.push('invalid value for "workflow_id", workflow_id cannot be nil.')
  end

  if !@tags.nil? && @tags.length > 30
    invalid_properties.push('invalid value for "tags", number of items must be less than or equal to 30.')
  end

  if !@customer_user_id.nil? && @customer_user_id.to_s.length > 256
    invalid_properties.push('invalid value for "customer_user_id", the character length must be smaller than or equal to 256.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



442
443
444
# File 'lib/onfido/models/workflow_run.rb', line 442

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



448
449
450
451
452
453
454
455
456
457
458
459
460
# File 'lib/onfido/models/workflow_run.rb', line 448

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



436
437
438
# File 'lib/onfido/models/workflow_run.rb', line 436

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



270
271
272
273
274
275
276
277
278
# File 'lib/onfido/models/workflow_run.rb', line 270

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @applicant_id.nil?
  return false if @workflow_id.nil?
  return false if !@tags.nil? && @tags.length > 30
  return false if !@customer_user_id.nil? && @customer_user_id.to_s.length > 256
  return false if @id.nil?
  true
end