Class: Onfido::Configuration

Inherits:
Object
  • Object
show all
Defined in:
lib/onfido/configuration.rb

Constant Summary collapse

REGIONS =
{
  EU: 'eu',
  CA: 'ca',
  US: 'us'
}.freeze

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize {|_self| ... } ⇒ Configuration

Returns a new instance of Configuration.

Yields:

  • (_self)

Yield Parameters:



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/onfido/configuration.rb', line 165

def initialize
  @scheme = 'https'
  @host = 'api.eu.onfido.com'
  @base_path = '/v3.6'
  @server_index = nil
  @server_operation_index = {}
  @server_variables = {}
  @server_operation_variables = {}
  @api_key = {}
  @api_key_prefix = {}
  @client_side_validation = true
  @ssl_verify = true
  @ssl_verify_mode = nil
  @ssl_ca_file = nil
  @ssl_client_cert = nil
  @ssl_client_key = nil
  @middlewares = Hash.new { |h, k| h[k] = [] }
  @configure_connection_blocks = []
  @timeout = 30
  # return data as binary instead of file
  @return_binary_data = false
  @params_encoder = nil
  @debugging = false
  @ignore_operation_servers = false
  @inject_format = false
  @force_ending_format = false
  @logger = defined?(Rails) ? Rails.logger : Logger.new(STDOUT)

  use( Faraday::FollowRedirects::Middleware ) 

  yield(self) if block_given?
end

Instance Attribute Details

#access_tokenObject

Defines the access token (Bearer) used with OAuth2.



70
71
72
# File 'lib/onfido/configuration.rb', line 70

def access_token
  @access_token
end

#access_token_getterProc

Defines a Proc used to fetch or refresh access tokens (Bearer) used with OAuth2. Overrides the access_token if set

Returns:

  • (Proc)


75
76
77
# File 'lib/onfido/configuration.rb', line 75

def access_token_getter
  @access_token_getter
end

#api_keyHash

Defines API keys used with API Key authentications.

Examples:

parameter name is “api_key”, API key is “xxx” (e.g. “api_key=xxx” in query string)

config.api_key['api_key'] = 'xxx'

Returns:

  • (Hash)

    key: parameter name, value: parameter value (API key)



49
50
51
# File 'lib/onfido/configuration.rb', line 49

def api_key
  @api_key
end

#api_key_prefixHash

Defines API key prefixes used with API Key authentications.

Examples:

parameter name is “Authorization”, API key prefix is “Token” (e.g. “Authorization: Token xxx” in headers)

config.api_key_prefix['api_key'] = 'Token'

Returns:

  • (Hash)

    key: parameter name, value: API key prefix



57
58
59
# File 'lib/onfido/configuration.rb', line 57

def api_key_prefix
  @api_key_prefix
end

#base_pathObject

Defines url base path



29
30
31
# File 'lib/onfido/configuration.rb', line 29

def base_path
  @base_path
end

#client_side_validationtrue, false

Set this to false to skip client side validation in the operation. Default to true.

Returns:

  • (true, false)


117
118
119
# File 'lib/onfido/configuration.rb', line 117

def client_side_validation
  @client_side_validation
end

#debuggingtrue, false

Set this to enable/disable debugging. When enabled (set to true), HTTP request/response details will be logged with ‘logger.debug` (see the `logger` attribute). Default to false.

Returns:

  • (true, false)


87
88
89
# File 'lib/onfido/configuration.rb', line 87

def debugging
  @debugging
end

#force_ending_formatObject

Returns the value of attribute force_ending_format.



163
164
165
# File 'lib/onfido/configuration.rb', line 163

def force_ending_format
  @force_ending_format
end

#hostObject

Defines url host



26
27
28
# File 'lib/onfido/configuration.rb', line 26

def host
  @host
end

#ignore_operation_serverstrue, false

Set this to ignore operation servers for the API client. This is useful when you need to send requests to a different server than the one specified in the OpenAPI document. Will default to the base url defined in the spec but can be overridden by setting ‘scheme`, `host`, `base_path` directly. Default to false.

Returns:

  • (true, false)


95
96
97
# File 'lib/onfido/configuration.rb', line 95

def ignore_operation_servers
  @ignore_operation_servers
end

#inject_formatObject

Returns the value of attribute inject_format.



161
162
163
# File 'lib/onfido/configuration.rb', line 161

def inject_format
  @inject_format
end

#logger#debug

Defines the logger used for debugging. Default to ‘Rails.logger` (when in Rails) or logging to STDOUT.

Returns:

  • (#debug)


101
102
103
# File 'lib/onfido/configuration.rb', line 101

def logger
  @logger
end

#params_encoderObject

Set this to customize parameters encoder of array parameter. Default to nil. Faraday uses NestedParamsEncoder when nil.

github.com/lostisland/faraday/tree/main/lib/faraday/encoders

See Also:

  • params_encoder option of Faraday. Related source code:


158
159
160
# File 'lib/onfido/configuration.rb', line 158

def params_encoder
  @params_encoder
end

#passwordString

Defines the password used with HTTP basic authentication.

Returns:

  • (String)


67
68
69
# File 'lib/onfido/configuration.rb', line 67

def password
  @password
end

#proxyObject

Proxy setting HTTP Proxy settings



151
152
153
# File 'lib/onfido/configuration.rb', line 151

def proxy
  @proxy
end

#return_binary_dataObject

Set this to return data as binary instead of downloading a temp file. When enabled (set to true) HTTP responses with return type ‘File` will be returned as a stream of binary data. Default to false.



80
81
82
# File 'lib/onfido/configuration.rb', line 80

def return_binary_data
  @return_binary_data
end

#schemeObject

Defines url scheme



23
24
25
# File 'lib/onfido/configuration.rb', line 23

def scheme
  @scheme
end

#server_indexObject

Define server configuration index



32
33
34
# File 'lib/onfido/configuration.rb', line 32

def server_index
  @server_index
end

#server_operation_indexObject

Define server operation configuration index



35
36
37
# File 'lib/onfido/configuration.rb', line 35

def server_operation_index
  @server_operation_index
end

#server_operation_variablesObject

Default server operation variables



41
42
43
# File 'lib/onfido/configuration.rb', line 41

def server_operation_variables
  @server_operation_variables
end

#server_variablesObject

Default server variables



38
39
40
# File 'lib/onfido/configuration.rb', line 38

def server_variables
  @server_variables
end

#ssl_ca_fileString

TLS/SSL setting Set this to customize the certificate file to verify the peer.

Returns:

  • (String)

    the path to the certificate file



139
140
141
# File 'lib/onfido/configuration.rb', line 139

def ssl_ca_file
  @ssl_ca_file
end

#ssl_client_certObject

TLS/SSL setting Client certificate file (for client certificate)



143
144
145
# File 'lib/onfido/configuration.rb', line 143

def ssl_client_cert
  @ssl_client_cert
end

#ssl_client_keyObject

TLS/SSL setting Client private key file (for client certificate)



147
148
149
# File 'lib/onfido/configuration.rb', line 147

def ssl_client_key
  @ssl_client_key
end

#ssl_verifytrue, false

Note:

Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.

TLS/SSL setting Set this to false to skip verifying SSL certificate when calling API from https server. Default to true.

Returns:

  • (true, false)


126
127
128
# File 'lib/onfido/configuration.rb', line 126

def ssl_verify
  @ssl_verify
end

#ssl_verify_modeObject

Note:

Do NOT set it to false in production code, otherwise you would face multiple types of cryptographic attacks.

TLS/SSL setting Any ‘OpenSSL::SSL::` constant (see ruby-doc.org/stdlib-2.5.1/libdoc/openssl/rdoc/OpenSSL/SSL.html)



133
134
135
# File 'lib/onfido/configuration.rb', line 133

def ssl_verify_mode
  @ssl_verify_mode
end

#temp_folder_pathString

Defines the temporary folder to store downloaded files (for API endpoints that have file response). Default to use ‘Tempfile`.

Returns:

  • (String)


108
109
110
# File 'lib/onfido/configuration.rb', line 108

def temp_folder_path
  @temp_folder_path
end

#timeoutObject

The time limit for HTTP request in seconds. Default to 0 (never times out).



112
113
114
# File 'lib/onfido/configuration.rb', line 112

def timeout
  @timeout
end

#usernameString

Defines the username used with HTTP basic authentication.

Returns:

  • (String)


62
63
64
# File 'lib/onfido/configuration.rb', line 62

def username
  @username
end

Class Method Details

.defaultObject

The default Configuration object.



199
200
201
# File 'lib/onfido/configuration.rb', line 199

def self.default
  @@default ||= Configuration.new
end

Instance Method Details

#access_token_with_refreshObject

Gets access_token using access_token_getter or uses the static access_token



264
265
266
267
# File 'lib/onfido/configuration.rb', line 264

def access_token_with_refresh
  return access_token if access_token_getter.nil?
  access_token_getter.call
end

#api_key_with_prefix(param_name, param_alias = nil) ⇒ Object

Gets API key (with prefix if set).

Parameters:

  • param_name (String)

    the parameter name of API key auth



253
254
255
256
257
258
259
260
261
# File 'lib/onfido/configuration.rb', line 253

def api_key_with_prefix(param_name, param_alias = nil)
  key = @api_key[param_name]
  key = @api_key.fetch(param_alias, key) unless param_alias.nil?
  if @api_key_prefix[param_name]
    "#{@api_key_prefix[param_name]} #{key}"
  else
    key
  end
end

#api_token=(api_token) ⇒ Object



234
235
236
# File 'lib/onfido/configuration.rb', line 234

def api_token=(api_token)
  @api_key = {'Token' => "Token token=#{api_token}"}
end

#auth_settingsObject

Returns Auth Settings hash for api client.



275
276
277
278
279
280
281
282
283
284
285
# File 'lib/onfido/configuration.rb', line 275

def auth_settings
  {
    'Token' =>
      {
        type: 'api_key',
        in: 'header',
        key: 'Authorization',
        value: api_key_with_prefix('Token')
      },
  }
end

#base_url(operation = nil) ⇒ Object

Returns base URL for specified operation based on server settings



224
225
226
227
228
229
230
231
232
# File 'lib/onfido/configuration.rb', line 224

def base_url(operation = nil)
  return "#{scheme}://#{[host, base_path].join('/').gsub(/\/+/, '/')}".sub(/\/+\z/, '') if ignore_operation_servers
  if operation_server_settings.key?(operation) then
    index = server_operation_index.fetch(operation, server_index)
    server_url(index.nil? ? 0 : index, server_operation_variables.fetch(operation, server_variables), operation_server_settings[operation])
  else
    server_index.nil? ? "#{scheme}://#{[host, base_path].join('/').gsub(/\/+/, '/')}".sub(/\/+\z/, '') : server_url(server_index, server_variables, nil)
  end
end

#basic_auth_tokenObject

Gets Basic Auth token string



270
271
272
# File 'lib/onfido/configuration.rb', line 270

def basic_auth_token
  'Basic ' + ["#{username}:#{password}"].pack('m').delete("\r\n")
end

#configure {|_self| ... } ⇒ Object

Yields:

  • (_self)

Yield Parameters:



203
204
205
# File 'lib/onfido/configuration.rb', line 203

def configure
  yield(self) if block_given?
end

#configure_connection(conn) ⇒ Object



367
368
369
370
371
# File 'lib/onfido/configuration.rb', line 367

def configure_connection(conn)
  @configure_connection_blocks.each do |block|
    block.call(conn)
  end
end

#configure_faraday_connection(&block) ⇒ Object

Configure Faraday connection directly.

“‘ c.configure_faraday_connection do |conn|

conn.use Faraday::HttpCache, shared_cache: false, logger: logger
conn.response :logger, nil, headers: true, bodies: true, log_level: :debug do |logger|
  logger.filter(/(Authorization: )(.*)/, '\1[REDACTED]')
end

end

c.configure_faraday_connection do |conn|

conn.adapter :typhoeus

end “‘

Parameters:

  • block (Proc)

    ‘#call`able object that takes one arg, the connection



363
364
365
# File 'lib/onfido/configuration.rb', line 363

def configure_faraday_connection(&block)
  @configure_connection_blocks << block
end

#configure_middleware(connection) ⇒ Object

Set up middleware on the connection



410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
# File 'lib/onfido/configuration.rb', line 410

def configure_middleware(connection)
  return if @middlewares.empty?

  [:request, :response, :use, :insert, :insert_before, :insert_after, :swap].each do |operation|
    next unless @middlewares.key?(operation)

    @middlewares[operation].each do |key, args, block|
      connection.builder.send(operation, key, *args, &block)
    end
  end

  if @middlewares.key?(:delete)
    @middlewares[:delete].each do |key, _args, _block|
      connection.builder.delete(key)
    end
  end
end

#operation_server_settingsObject



308
309
310
311
# File 'lib/onfido/configuration.rb', line 308

def operation_server_settings
  {
  }
end

#regionObject



238
239
240
# File 'lib/onfido/configuration.rb', line 238

def region()
  REGIONS
end

#region=(region) ⇒ Object



242
243
244
245
# File 'lib/onfido/configuration.rb', line 242

def region=(region)
  @server_index = 0
  server_variables[:region] = region
end

#request(*middleware) ⇒ Object

Adds request middleware to the stack



379
380
381
# File 'lib/onfido/configuration.rb', line 379

def request(*middleware)
  set_faraday_middleware(:request, *middleware)
end

#response(*middleware) ⇒ Object

Adds response middleware to the stack



384
385
386
# File 'lib/onfido/configuration.rb', line 384

def response(*middleware)
  set_faraday_middleware(:response, *middleware)
end

#server_settingsObject

Returns an array of Server setting



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/onfido/configuration.rb', line 288

def server_settings
  [
    {
      url: "https://api.{region}.onfido.com/v3.6",
      description: "No description provided",
      variables: {
        region: {
            description: "No description provided",
            default_value: "eu",
            enum_values: [
              "eu",
              "us",
              "ca"
            ]
          }
        }
    }
  ]
end

#server_url(index, variables = {}, servers = nil) ⇒ Object

Returns URL based on server settings

Parameters:

  • index

    array index of the server settings

  • variables (defaults to: {})

    hash of variable and the corresponding value



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/onfido/configuration.rb', line 317

def server_url(index, variables = {}, servers = nil)
  servers = server_settings if servers == nil

  # check array index out of bound
  if (index.nil? || index < 0 || index >= servers.size)
    fail ArgumentError, "Invalid index #{index} when selecting the server. Must not be nil and must be less than #{servers.size}"
  end

  server = servers[index]
  url = server[:url]

  return url unless server.key? :variables

  # go through variable and assign a value
  server[:variables].each do |name, variable|
    if variables.key?(name)
      if (!server[:variables][name].key?(:enum_values) || server[:variables][name][:enum_values].include?(variables[name]))
        url.gsub! "{" + name.to_s + "}", variables[name]
      else
        fail ArgumentError, "The variable `#{name}` in the server URL has invalid value #{variables[name]}. Must be #{server[:variables][name][:enum_values]}."
      end
    else
      # use default value
      url.gsub! "{" + name.to_s + "}", server[:variables][name][:default_value]
    end
  end

  url
end

#set_faraday_middleware(operation, key, *args, &block) ⇒ Object

Adds Faraday middleware setting information to the stack

Examples:

Use the ‘set_faraday_middleware` method to set middleware information

config.set_faraday_middleware(:request, :retry, max: 3, methods: [:get, :post], retry_statuses: [503])
config.set_faraday_middleware(:response, :logger, nil, { bodies: true, log_level: :debug })
config.set_faraday_middleware(:use, Faraday::HttpCache, store: Rails.cache, shared_cache: false)
config.set_faraday_middleware(:insert, 0, FaradayMiddleware::FollowRedirects, { standards_compliant: true, limit: 1 })
config.set_faraday_middleware(:swap, 0, Faraday::Response::Logger)
config.set_faraday_middleware(:delete, Faraday::Multipart::Middleware)

See Also:



399
400
401
402
403
404
405
406
# File 'lib/onfido/configuration.rb', line 399

def set_faraday_middleware(operation, key, *args, &block)
  unless [:request, :response, :use, :insert, :insert_before, :insert_after, :swap, :delete].include?(operation)
    fail ArgumentError, "Invalid faraday middleware operation #{operation}. Must be" \
                        " :request, :response, :use, :insert, :insert_before, :insert_after, :swap or :delete."
  end

  @middlewares[operation] << [key, args, block]
end

#use(*middleware) ⇒ Object

Adds middleware to the stack



374
375
376
# File 'lib/onfido/configuration.rb', line 374

def use(*middleware)
  set_faraday_middleware(:use, *middleware)
end